"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var messages_1 = require("./messages");
var constants_1 = require("./constants");
var paths_1 = require("../config/paths");
var execa = require("execa");
function getDevPendencies(options) {
    return tslib_1.__spreadArrays(constants_1.devDependencies, (options.react ? constants_1.devDependenciesForReact : []), (options.docz ? constants_1.devDependenciesForDocz : []), (options.doczGithubPages ? constants_1.devDependenciesForGhpages : []), (options.monorepo ? constants_1.monorepoDevDependencies : []));
}
/**
 * 执行安装依赖的命令
 *
 * @param projectName 项目名称
 * @param deps 依赖
 * @param isDev 是否是开发依赖
 */
function execInstallDeps(projectName, deps, isDev, monorepo) {
    if (isDev === void 0) { isDev = false; }
    if (monorepo === void 0) { monorepo = false; }
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var cmd, args;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    cmd = ts_lib_scripts_utils_1.getInstallCmd();
                    args = tslib_1.__spreadArrays([
                        cmd === 'npm' ? 'i' : 'add'
                    ], deps, [
                        isDev ? '--dev' : '',
                        cmd === 'npm' ? '--save' : '',
                        monorepo ? '-W' : '',
                    ]).filter(Boolean);
                    return [4 /*yield*/, execa(cmd, args, {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
/**
 * 安装依赖
 *
 * @param {CreateOptions} options
 */
function installDeps(spinner, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var projectName, devDeps, error_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectName = options.projectName;
                    devDeps = getDevPendencies(options);
                    spinner.start(messages_1.dependenciesMessage(constants_1.dependencies, devDeps));
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 4, , 5]);
                    return [4 /*yield*/, execInstallDeps(projectName, constants_1.dependencies, false, true)];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, execInstallDeps(projectName, devDeps, true, true)];
                case 3:
                    _a.sent();
                    spinner.succeed('安装依赖包');
                    messages_1.successMessage(ts_lib_scripts_utils_1.getInstallCmd(), projectName);
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    spinner.fail("\u5B89\u88C5\u4F9D\u8D56\u5931\u8D25");
                    messages_1.failureMessage([
                        ts_lib_scripts_utils_1.getInstallDepsCmd(constants_1.dependencies),
                        ts_lib_scripts_utils_1.getInstallDepsCmd(devDeps, true),
                    ]);
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5: return [2 /*return*/];
            }
        });
    });
}
exports.default = installDeps;
//# sourceMappingURL=installDeps.js.map